@@ -33,6 +33,7 @@ from calibre.gui2.preferences.coloring import EditRules
 from calibre.gui2.library.alternate_views import auto_height, CM_TO_INCH
 from calibre.gui2.widgets2 import Dialog
 
+
 class BusyCursor(object):
 
     def __enter__(self):
@@ -43,6 +44,7 @@ class BusyCursor(object):
 
 # IdLinksEditor {{{
 
+
 class IdLinksRuleEdit(Dialog):
 
     def __init__(self, key='', name='', template='', parent=None):
@@ -62,7 +64,7 @@ class IdLinksRuleEdit(Dialog):
         self.key = k = QLineEdit(self)
         l.addRow(_('&Key:'), k)
         l.addRow(QLabel(_(
-            'The name that will appear in the book details panel')))
+            'The name that will appear in the Book details panel')))
         self.nw = n = QLineEdit(self)
         l.addRow(_('&Name:'), n)
         la = QLabel(_(
@@ -83,6 +85,7 @@ class IdLinksRuleEdit(Dialog):
                     'The %s field cannot be empty') % which, show=True)
         Dialog.accept(self)
 
+
 class IdLinksEditor(Dialog):
 
     def __init__(self, parent=None):
@@ -150,6 +153,7 @@ class IdLinksEditor(Dialog):
             self.table.removeRow(r)
 # }}}
 
+
 class DisplayedFields(QAbstractListModel):  # {{{
 
     def __init__(self, db, parent=None):
@@ -224,6 +228,7 @@ class DisplayedFields(QAbstractListModel):  # {{{
 
 # }}}
 
+
 class Background(QWidget):  # {{{
 
     def __init__(self, parent):
@@ -239,7 +244,13 @@ class Background(QWidget):  # {{{
             from calibre.gui2.preferences.texture_chooser import texture_path
             path = texture_path(self.btex)
             if path:
-                self.brush.setTexture(QPixmap(path))
+                p = QPixmap(path)
+                try:
+                    dpr = self.devicePixelRatioF()
+                except AttributeError:
+                    dpr = self.devicePixelRatio()
+                p.setDevicePixelRatio(dpr)
+                self.brush.setTexture(p)
         self.update()
 
     def sizeHint(self):
@@ -251,6 +262,7 @@ class Background(QWidget):  # {{{
         painter.end()
 # }}}
 
+
 class ConfigWidget(ConfigWidgetBase, Ui_Form):
 
     size_calculated = pyqtSignal(object)
@@ -272,6 +284,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         r('ui_style', gprefs, restart_required=True, choices=[(_('System default'), 'system'), (_('Calibre style'),
                     'calibre')])
         r('book_list_tooltips', gprefs)
+        r('row_numbers_in_book_list', gprefs)
         r('tag_browser_old_look', gprefs, restart_required=True)
         r('tag_browser_hide_empty_categories', gprefs)
         r('bd_show_cover', gprefs)
@@ -282,11 +295,15 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         r('cover_grid_disk_cache_size', gprefs)
         r('cover_grid_spacing', gprefs)
         r('cover_grid_show_title', gprefs)
+        r('tag_browser_show_counts', gprefs)
 
         r('cover_flow_queue_length', config, restart_required=True)
         r('cover_browser_reflections', gprefs)
-        r('show_rating_in_cover_browser', gprefs)
         r('cover_browser_title_template', db.prefs)
+        fm = db.field_metadata
+        r('cover_browser_subtitle_field', db.prefs, choices=[(_('No subtitle'), 'none')] + sorted(
+            (fm[k].get('name'), k) for k in fm.all_field_keys() if fm[k].get('name')
+        ))
         r('emblem_size', gprefs)
         r('emblem_position', gprefs, choices=[
             (_('Left'), 'left'), (_('Top'), 'top'), (_('Right'), 'right'), (_('Bottom'), 'bottom')])
@@ -534,7 +551,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
 
     def change_cover_grid_color(self):
         col = QColorDialog.getColor(self.cg_bg_widget.bcol,
-                              self.gui, _('Choose background color for cover grid'))
+                              self.gui, _('Choose background color for the Cover grid'))
         if col.isValid():
             col = tuple(col.getRgb())[:3]
             self.set_cg_color(col)
@@ -628,12 +645,17 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         self.update_font_display()
         gui.tags_view.reread_collapse_parameters()
         gui.library_view.refresh_book_details()
+        gui.library_view.set_row_header_visibility()
         gui.cover_flow.setShowReflections(gprefs['cover_browser_reflections'])
         gui.cover_flow.setPreserveAspectRatio(gprefs['cb_preserve_aspect_ratio'])
+        gui.update_cover_flow_subtitle_font()
         gui.cover_flow.template_inited = False
+        for view in 'library memory card_a card_b'.split():
+            getattr(gui, view + '_view').set_row_header_visibility()
         gui.library_view.refresh_row_sizing()
         gui.grid_view.refresh_settings()
 
+
 if __name__ == '__main__':
     from calibre.gui2 import Application
     app = Application([])
